ActionController::Routing::Routes.draw do | map |

  # Helper method to make named routes easier (from a RailsCast)

  # def map.controller_actions( controller, actions )
  #   actions.each do | action |
  #     self.send(
  #       "#{controller}_#{action}",
  #       "#{controller}/#{action}",
  #       :controller => controller,
  #       :action => action
  #     )
  #   end
  # end

  # Map root to the User account home page

  map.home PATH_PREFIX + '/', :controller => 'users', :action => 'home'

  # Mapping for the OpenID login system. The signin and signout
  # entries are for more readable paths in views; they're just
  # aliases for 'new' and 'destroy' actions.

  map.open_id_complete PATH_PREFIX + '/session', :controller => 'sessions', :action => 'create', :requirements => { :method => :get }
  map.resource :session, :path_prefix => PATH_PREFIX

  map.signin  PATH_PREFIX + '/signin',  :controller => 'sessions', :action => 'new'
  map.signout PATH_PREFIX + '/signout', :controller => 'sessions', :action => 'destroy'

  # Allow in-progress account signup to be cancelled

  map.user_cancel PATH_PREFIX + '/users/cancel/:id', :controller => 'users', :action => 'cancel'

  # Get common named routes for our resources

  map.resources :customers,      :has_many => [ :tasks                  ], :path_prefix => PATH_PREFIX
  map.resources :projects,       :has_many => [ :tasks                  ], :path_prefix => PATH_PREFIX
  map.resources :control_panels, :has_many => [ :tasks                  ], :path_prefix => PATH_PREFIX
  map.resources :users,          :has_many => [ :tasks, :timesheets     ], :path_prefix => PATH_PREFIX
  map.resources :tasks,          :has_many => [ :users, :timesheet_rows ], :path_prefix => PATH_PREFIX
  map.resources :timesheets,     :has_many => [ :timesheet_rows         ], :path_prefix => PATH_PREFIX
  map.resources :audits,                                                   :path_prefix => PATH_PREFIX
  map.resources :reports,                                                  :path_prefix => PATH_PREFIX
  map.resources :charts,                                                   :path_prefix => PATH_PREFIX
  map.resources :task_imports,                                             :path_prefix => PATH_PREFIX

  # Finally, the normal default rules at lowest priority

  map.connect PATH_PREFIX + '/:controller/:action/:id'
  map.connect PATH_PREFIX + '/:controller/:action/:id.:format'
end
